function [m,y0,r,phi] = geradevek(x1,y1,x2,y2)
%GERADEVEK Geradengleichung aus Koordinaten-Vektoren bestimmen.
%
%   [m,y0,r,phi] = GERADEVEK(x1,y1) berechnet aus den kartesischen 
%   Koordinaten P1 (x1,y1) die Paramter m und y0 der Geradengleichung 
%   y = m * x sowie den Abstand r des Punktes P1 vom Koordinatenursprung 
%   und seinen Winkel phi zur x-Achse in Grad. 
%   Hierbei knnen x1 und y1 auch Vektoren sein!
%
%   [m,y0] = GERADEVEK(x1,y1,x2,y2) berechnet aus den beiden kartesischen 
%   Koordinaten P1 (x1,y1) und P2 (x2,y2) einer Gerade die Parameter 
%   m und y0 der Geradengleichung y = m * x + y0.
%   Hierbei knnen x1, y1, x2 und y2 auch Vektoren sein!

% geradevec.m
% Kapitel 3.7.5 bungsaufgaben

if nargin == 0
    x1 = [1 1];
    y1 = [2 2];
    x2 = [3 2];
    y2 = [1 4];
    disp ('===============================================')
    disp ('DEMO geradevek: ')
    disp ('===============================================')
    disp (' a) [m,y0] = geradevek(1,2,3,1)')
    [m, y0] = geradevek (x1(1), y1(1), x2(1), y2(1)) 
    figure
        subplot (221)
        axis ([0 5 -1 5]);
        hold on
        grid on        
        title ('a) geradevek(1,2,3,1)')
        plot ([x1(1) x2(1)], [y1(1) y2(1)], 'bo-')
        text (x1(1)+0.5, y1(1)+0.3, ['P_1 = (',num2str(x1(1)),',',num2str(y1(1)),')'])
        text (x2(1),     y2(1)-0.6, ['P_2 = (',num2str(x2(1)),',',num2str(y2(1)),')'])
        text (0.5,       -0.5,      ['m = ',num2str(m),', y0 = ',num2str(y0)])
    disp ('===============================================')
    disp (' b) [m,y0] =  geradevek(1,2,2,4)')
    [m, y0] = geradevek (x1(2), y1(2), x2(2), y2(2)) 
        subplot (222)
        axis ([0 5 -1 5])
        hold on
        grid on        
        title ('b) geradevek(1,2,2,4)')
        plot ([x1(2) x2(2)], [y1(2) y2(2)], 'bo-')
        text (x1(1)+0.5, y1(1)+0.3, ['P_3 = (',num2str(x1(1)),',',num2str(y1(1)),')'])
        text (x2(2)+0.5, y2(2),     ['P_4 = (',num2str(x2(2)),',',num2str(y2(2)),')'])
        text (0.5,       -0.5,      ['m = ',num2str(m),', y0 = ',num2str(y0)])
    disp ('===============================================')
    disp (' c) [m,y0] = geradevek([1 1],[2 2],[3 2],[1 4])')
    [m, y0] = geradevek (x1, y1, x2, y2)
        subplot (223)
        axis ([0 5 -1 5])
        hold on
        grid on
        title ('c) geradevek([1 1],[2 2],[3 2],[1 4])')
        plot ([x1(1) x2(1)], [y1(1) y2(1)], 'bo-')
        plot ([x1(2) x2(2)], [y1(2) y2(2)], 'bo-')
        text (x1(1)+0.5, y1(1)+0.3, ['P_1 = P_3 = (',num2str(x1(1)),',',num2str(y1(1)),')'])
        text (x2(1),     y2(1)-0.6, ['P_2 = (',num2str(x2(1)),',',num2str(y2(1)),')'])
        text (x2(2)+0.5, y2(2),     ['P_4 (',num2str(x2(2)),',',num2str(y2(2)),')'])
        text (0.5,       -0.5,      ['m = [',num2str(m(1)),' ',num2str(m(2)),'], ',...
                                     'y0 = [',num2str(y0(1)),' ',num2str(y0(2)),']'])
    disp ('===============================================')
    x1 = [0 -2];
    y1 = [4  1];
    disp (' d) [m,y0,r,phi] = geradevek([0 -2],[4 1])')
    [m, y0, r, phi] = geradevek (x1, y1) 
        subplot (224)
        axis ([-3 3 -1 5])
        hold on
        grid on
        title ('d) geradevek([0 -2],[4 1])')
        plot ([0 x1(1)], [0 y1(1)], 'bo-')
        plot ([0 x1(2)], [0 y1(2)], 'bo-')
        text (x1(1)+.2, y1(1)+0.2, ['P_1 = (',num2str(x1(1)),',',num2str(y1(1)),')'])
        text (x1(2),    y1(2)+0.4, ['P_2 = (',num2str(x1(2)),',',num2str(y1(2)),')'])
        text (-2.5,     -0.5,      ['m = [',num2str(m(1)),' ',num2str(m(2)),'], ',...
                                    'y0 = [',num2str(y0(1)),' ',num2str(y0(2)),']'])
    disp ('===============================================')
    
elseif nargin == 2
    y0  = zeros (size (x1));
    r   = sqrt (x1.^2 + y1.^2);
    x0  = find (x1==0);              % Indizes der Elemente von x1 gleich Null
    xn0 = find (~x1==0);             % Indizes der Elemente von x1 ungleich Null
    m (xn0)   = y1 (xn0) ./ x1 (xn0);
    phi (xn0) = sign (y1 (xn0)) .* atan2 (y1 (xn0), x1 (xn0)) * 180/pi;
    if x0
        disp (['Steigung m +/- unendlich fr Punkt(e) ', num2str(x0),' !'])
        m (x0)    = sign (y1 (x0)) * inf;
        phi (x0)  = sign (y1 (x0)) * 90;
    end
    
elseif nargin == 4
    r   = [];
    phi = [];
    x0  = find (x1==x2);             % Indizes der Elemente von x1 gleich x2 
    xn0 = find (~(x1==x2));          % Indizes der Elemente von x1 ungleich x2 
    m (xn0)  = (y2 (xn0) - y1 (xn0)) ./ (x2 (xn0) - x1 (xn0));
    y0 (xn0) = (x2(xn0).*y1(xn0) - x1(xn0).*y2(xn0)) ./ (x2(xn0)-x1(xn0));
    if x0
        disp (['Steigung m +/- unendlich fr Punkt(e) ',num2str(x0),' !'])
        m (x0)   = sign (y2 (x0) - y1 (x0)) * inf;
        y0 (x0)  = 0 * x1 (x0);
    end
    
else
    disp ('Falsche Anzahl von Parametern!')
    help gerade
end
